intelmq.bots.outputs.amqptopic package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.outputs.amqptopic package

## Submodules

## intelmq.bots.outputs.amqptopic.output module

class `intelmq.bots.outputs.amqptopic.output.` `AMQPTopicOutputBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.OutputBot`

  `connect_server`()
  `connection` = None
  `init`()
  `process`()

    Stop the Bot if cannot connect to AMQP Server after the defined connection attempts

  `shutdown`()

`intelmq.bots.outputs.amqptopic.output.` `BOT`

  alias of `intelmq.bots.outputs.amqptopic.output.AMQPTopicOutputBot`

## Module contents